==> haskell-persistent-sqlite-2.2.1-11-armv7h.pkg.tar.xz: usr/share/haskell/haskell-persistent-sqlite/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.2.1
id: persistent-sqlite-2.2.1-020805a595e48e0f78227359194c2b5e
key: persi_BMj2j1IM1QsGyjc3vOgZHH
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Sqlite Database.Persist.Sqlite
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2.1
hs-libraries: HSpersistent-sqlite-2.2.1-BMj2j1IM1QsGyjc3vOgZHH
extra-libraries:
    pthread
depends:
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-9cbf21b79aba616188d311eceb1fecef
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    monad-logger-0.3.18-d371de410ef611b2a9194c84cfcdfbf6
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    persistent-2.2.4.1-840a8f388c4f74e927e97d9dd2d8494d
    resourcet-1.1.7.3-7c6bcbec462b80120c27277d178fc6db
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.2.1-14-armv7h.pkg.tar.xz: usr/share/haskell/haskell-persistent-sqlite/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.2.1
id: persistent-sqlite-2.2.1-dc9bfdc32ca418df4843126baeec4677
key: persi_CzOhGNVDsIQA5jTiizBvHM
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Sqlite Database.Persist.Sqlite
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2.1
hs-libraries: HSpersistent-sqlite-2.2.1-CzOhGNVDsIQA5jTiizBvHM
extra-libraries:
    pthread
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
    monad-logger-0.3.18-868f3e43db7b68548caca5548a3e26c4
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    persistent-2.2.4.1-02dc8ce19066ae402489fff269c627fe
    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
